@@ -16,10 +16,10 @@ from ai.backend.client.exceptions import BackendAPIError, BackendClientError
 from ai.backend.client.request import Request
 from ai.backend.common.web.session import STORAGE_KEY, extra_config_headers, get_session
 
-from .auth import get_anonymous_session, get_api_session
+from .auth import fill_x_forwarded_for_header_to_api_session, get_anonymous_session, get_api_session
 from .logging import BraceStyleAdapter
 
-log = BraceStyleAdapter(logging.getLogger(__name__))
+log = BraceStyleAdapter(logging.getLogger(__spec__.name))  # type: ignore[name-defined]
 
 HTTP_HEADERS_TO_FORWARD = [
     "Accept-Language",
@@ -173,12 +173,7 @@ async def web_handler(request, *, is_anonymous=False) -> web.StreamResponse:
                 decrypted_payload_length = len(payload)
             else:
                 payload = request.content
-            # Send X-Forwarded-For header for token authentication with the client IP.
-            client_ip = request.headers.get("X-Forwarded-For")
-            if not client_ip:
-                client_ip = request.remote
-            _headers = {"X-Forwarded-For": client_ip}
-            api_session.aiohttp_session.headers.update(_headers)
+            fill_x_forwarded_for_header_to_api_session(request, api_session)
             # Deliver cookie for token-based authentication.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
             # We treat all requests and responses as streaming universally
@@ -271,12 +266,7 @@ async def web_plugin_handler(request, *, is_anonymous=False) -> web.StreamRespon
                 body["domain"] = request.app["config"]["api"]["domain"]
                 content = json.dumps(body).encode("utf8")
             request_api_version = request.headers.get("X-BackendAI-Version", None)
-            # Send X-Forwarded-For header for token authentication with the client IP.
-            client_ip = request.headers.get("X-Forwarded-For")
-            if not client_ip:
-                client_ip = request.remote
-            _headers = {"X-Forwarded-For": client_ip}
-            api_session.aiohttp_session.headers.update(_headers)
+            fill_x_forwarded_for_header_to_api_session(request, api_session)
             # Deliver cookie for token-based authentication.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
             api_rqst = Request(
@@ -363,6 +353,7 @@ async def websocket_handler(request, *, is_anonymous=False) -> web.StreamRespons
     try:
         async with api_session:
             request_api_version = request.headers.get("X-BackendAI-Version", None)
+            fill_x_forwarded_for_header_to_api_session(request, api_session)
             api_rqst = Request(
                 request.method,
                 path,
