@@ -32,6 +32,7 @@ from ai.backend.common.web.session import setup as setup_session
 from ai.backend.common.web.session.redis_storage import RedisStorage
 
 from . import __version__, user_agent
+from .auth import fill_x_forwarded_for_header_to_api_session, get_client_ip
 from .config import config_iv
 from .logging import BraceStyleAdapter
 from .proxy import decrypt_payload, web_handler, web_plugin_handler, websocket_handler
@@ -188,6 +189,7 @@ async def login_handler(request: web.Request) -> web.Response:
         )
     request_headers = extra_config_headers.check(request.headers)
     secure_context = request_headers.get("X-BackendAI-Encoded", None)
+    client_ip = get_client_ip(request)
     if not secure_context:
         # For non-encrypted requests, just read the body as-is.
         # Encrypted requests are handled by the `decrypt_payload` middleware.
@@ -265,9 +267,10 @@ async def login_handler(request: web.Request) -> web.Response:
     last_login_attempt = login_time
     if login_fail_count >= ALLOWED_FAIL_COUNT:
         log.info(
-            "Too many consecutive login attempts for {}: {}",
+            "LOGIN_HANDLER: Too many consecutive login fails (email:{}, count:{}, ip:{})",
             creds["username"],
             login_fail_count,
+            client_ip,
         )
         await _set_login_history(last_login_attempt, login_fail_count)
         return web.HTTPTooManyRequests(
@@ -291,6 +294,7 @@ async def login_handler(request: web.Request) -> web.Response:
         )
         assert anon_api_config.is_anonymous
         async with APISession(config=anon_api_config) as api_session:
+            fill_x_forwarded_for_header_to_api_session(request, api_session)
             token = await api_session.User.authorize(creds["username"], creds["password"])
             stored_token = {
                 "type": "keypair",
@@ -310,6 +314,11 @@ async def login_handler(request: web.Request) -> web.Response:
             result["data"] = public_return  # store public info from token
             login_fail_count = 0
             await _set_login_history(last_login_attempt, login_fail_count)
+            log.info(
+                "LOGIN_HANDLER: Authorization succeeded for (email:{}, ip:{})",
+                creds["username"],
+                client_ip,
+            )
     except BackendClientError as e:
         # This is error, not failed login, so we should not update login history.
         return web.HTTPBadGateway(
@@ -323,7 +332,12 @@ async def login_handler(request: web.Request) -> web.Response:
             content_type="application/problem+json",
         )
     except BackendAPIError as e:
-        log.info("Authorization failed for {}: {}", creds["username"], e)
+        log.info(
+            "LOGIN_HANDLER: Authorization failed (email:{}, ip:{}) - {}",
+            creds["username"],
+            client_ip,
+            e,
+        )
         result["authenticated"] = False
         result["data"] = {
             "type": e.data.get("type"),
@@ -398,11 +412,7 @@ async def token_login_handler(request: web.Request) -> web.Response:
         )
         assert anon_api_config.is_anonymous
         async with APISession(config=anon_api_config) as api_session:
-            # Send X-Forwarded-For header for token authentication with the client IP.
-            client_ip = request.headers.get("X-Forwarded-For", request.remote)
-            if client_ip:
-                _headers = {"X-Forwarded-For": client_ip}
-                api_session.aiohttp_session.headers.update(_headers)
+            fill_x_forwarded_for_header_to_api_session(request, api_session)
             # Instead of email and password, cookie token will be used for auth.
             api_session.aiohttp_session.cookie_jar.update_cookies(request.cookies)
             token = await api_session.User.authorize("fake-email", "fake-pwd")
